==> libgtk-java-2.7.0.tar.gz: libgtk-java-2.7.0/src/java/org/gnu/gtk/SortType.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.javagnome.Enum;

/**
 * todo: doc
 * @see TreeViewColumn
 */
public class SortType extends Enum 
{
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    static final private int _ASCENDING = 0;
    static final public org.gnu.gtk.SortType ASCENDING = new org.gnu.gtk.SortType (_ASCENDING);
    static final private int _DESCENDING = 1;
    static final public org.gnu.gtk.SortType DESCENDING = new org.gnu.gtk.SortType (_DESCENDING);
    static final private org.gnu.gtk.SortType[] theInterned = new org.gnu.gtk.SortType[] 
    {
        ASCENDING, DESCENDING 
    }

;
    static private java.util.Hashtable theInternedExtras;
    static final private org.gnu.gtk.SortType theSacrificialOne = new org.gnu.gtk.SortType (0);
    static public org.gnu.gtk.SortType intern (int value) 
    {
        if (value < theInterned.length) 
        {
            return theInterned[value];
        }
        theSacrificialOne.value_ = value;
        if (theInternedExtras == null) 
        {
            theInternedExtras = new java.util.Hashtable();
        }
        org.gnu.gtk.SortType already = (org.gnu.gtk.SortType) theInternedExtras.get (
            theSacrificialOne);
        if (already == null) 
        {
            already = new org.gnu.gtk.SortType(value);
            theInternedExtras.put(already, already);
        }
        return already;
    }

    private SortType (int value) 
    {
        value_ = value;
    }

    public org.gnu.gtk.SortType or (org.gnu.gtk.SortType other) 
    {
        return intern(value_ | other.value_);
    }

    public org.gnu.gtk.SortType and (org.gnu.gtk.SortType other) 
    {
        return intern(value_ & other.value_);
    }

    public org.gnu.gtk.SortType xor (org.gnu.gtk.SortType other) 
    {
        return intern(value_ ^ other.value_);
    }

    public boolean test (org.gnu.gtk.SortType other) 
    {
        return (value_ & other.value_) == other.value_;
    }

    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}

==> libgtk-java-2.8.1.tar.gz: libgtk-java-2.8.1/src/java/org/gnu/gtk/SortType.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Enum;

/**
 * todo: doc
 * @see TreeViewColumn
 */
public class SortType extends Enum 
{
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    static final private int _ASCENDING = 0;
    static final public org.gnu.gtk.SortType ASCENDING = new org.gnu.gtk.SortType (_ASCENDING);
    static final private int _DESCENDING = 1;
    static final public org.gnu.gtk.SortType DESCENDING = new org.gnu.gtk.SortType (_DESCENDING);
    static final private org.gnu.gtk.SortType[] theInterned = new org.gnu.gtk.SortType[] 
    {
        ASCENDING, DESCENDING 
    }

;
    static private java.util.Hashtable theInternedExtras;
    static final private org.gnu.gtk.SortType theSacrificialOne = new org.gnu.gtk.SortType (0);
    static public org.gnu.gtk.SortType intern (int value) 
    {
        if (value < theInterned.length) 
        {
            return theInterned[value];
        }
        theSacrificialOne.value_ = value;
        if (theInternedExtras == null) 
        {
            theInternedExtras = new java.util.Hashtable();
        }
        org.gnu.gtk.SortType already = (org.gnu.gtk.SortType) theInternedExtras.get (
            theSacrificialOne);
        if (already == null) 
        {
            already = new org.gnu.gtk.SortType(value);
            theInternedExtras.put(already, already);
        }
        return already;
    }

    private SortType (int value) 
    {
        value_ = value;
    }

    public org.gnu.gtk.SortType or (org.gnu.gtk.SortType other) 
    {
        return intern(value_ | other.value_);
    }

    public org.gnu.gtk.SortType and (org.gnu.gtk.SortType other) 
    {
        return intern(value_ & other.value_);
    }

    public org.gnu.gtk.SortType xor (org.gnu.gtk.SortType other) 
    {
        return intern(value_ ^ other.value_);
    }

    public boolean test (org.gnu.gtk.SortType other) 
    {
        return (value_ & other.value_) == other.value_;
    }

    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}
